==> qore-1.14.2.tar.bz2: qore-1.14.2/docs/modules/MailMessage/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore MailMessage Module Reference", "index.html", [
    [ "MailMessage Module", "index.html", [
      [ "MailMessage Module Introduction", "index.html#mailmessageintro", null ],
      [ "MailMessage Release Notes", "index.html#mailmessage_relnotes", [
        [ "MailMessage 1.3.3", "index.html#mailmessage_v1_3_3", null ],
        [ "MailMessage 1.3.2", "index.html#mailmessage_v1_3_2", null ],
        [ "MailMessage 1.3.1", "index.html#mailmessage_v1_3_1", null ],
        [ "MailMessage 1.3", "index.html#mailmessage_v1_3", null ],
        [ "MailMessage 1.2.1", "index.html#mailmessage_v1_2_1", null ],
        [ "MailMessage 1.2", "index.html#mailmessage_v1_2", null ],
        [ "MailMessage 1.1", "index.html#mailmessage_v1_1", null ],
        [ "MailMessage 1.0.4", "index.html#mailmessage_v1_0_4", null ],
        [ "MailMessage 1.0.3", "index.html#mailmessage_v1_0_3", null ],
        [ "MailMessage 1.0.2", "index.html#mailmessage_v1_0_2", null ],
        [ "MailMessage 1.0.1", "index.html#mailmessage_v1_0_1", null ],
        [ "MailMessage 1.0", "index.html#mailmessage_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__crypto__transformations.html#ga5a725d566fde3fdf16cf967f24396d4f",
"group__error__constants.html#ga3468c62b4ca6805028a63d1a11ee9e56",
"group__hmac__functions.html#gaf88021aec5a7048984b0a0e5ce21733d",
"group__misc__functions.html#ga5802a4f147d02009947401dd92e3b197",
"group__pwd__functions.html#ga1584a4a9164ae9d500fca9b26452de75",
"group__tattr__input__mode__constants.html#ga2cd9fec271abb6f9352d02339d1580c4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.16.1.tar.bz2: qore-1.16.1/docs/modules/MailMessage/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore MailMessage Module Reference", "index.html", [
    [ "MailMessage Module", "index.html", "index" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__crypto__transformations.html#ga5a725d566fde3fdf16cf967f24396d4f",
"group__error__constants.html#ga3468c62b4ca6805028a63d1a11ee9e56",
"group__hmac__functions.html#gaf88021aec5a7048984b0a0e5ce21733d",
"group__misc__functions.html#ga5802a4f147d02009947401dd92e3b197",
"group__pwd__functions.html#ga1584a4a9164ae9d500fca9b26452de75",
"group__tattr__input__mode__constants.html#ga2cd9fec271abb6f9352d02339d1580c4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
